@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: lo_lowlevel.h,v 1.11 2005/08/09 15:06:04 mhabets Exp $
+ *  $Id: lo_lowlevel.h,v 1.15 2005/12/29 20:08:26 nhumfrey Exp $
  */
 
 #ifndef LO_LOWLEVEL_H
@@ -43,6 +43,9 @@ extern "C" {
  */
 typedef long double lo_hires;
 
+
+
+
 /**
  * \brief send a lo_message object to target targ
  *
@@ -52,15 +55,43 @@ typedef long double lo_hires;
  */
 int lo_send_message(lo_address targ, const char *path, lo_message msg);
 
+/**
+ * \brief send a lo_message object to target targ from address of serv
+ *
+ * This is slightly more efficient than lo_send if you want to send a lot of
+ * similar messages. The messages are constructed with the lo_message_new() and
+ * lo_message_add*() functions.
+ *
+ * \param targ The address to send the message to
+ * \param serv The server socket to send the message from
+ *              (can be NULL to use new socket)
+ * \param path The path to send the message to
+ * \param msg  The bundle itself
+ */
+int lo_send_message_from(lo_address targ, lo_server serv, 
+     const char *path, lo_message msg);
+
 /**
  * \brief send a lo_bundle object to address targ
  *
- * This is slightly more efficient than lo_send_bundled if you want to send a
- * lot of similar bundles. The bundles are constructed with the
+ * Bundles are constructed with the
  * lo_bundle_new() and lo_bundle_add_message() functions.
  */
 int lo_send_bundle(lo_address targ, lo_bundle b);
 
+/**
+ * \brief send a lo_bundle object to address targ from address of serv
+ *
+ * Bundles are constructed with the
+ * lo_bundle_new() and lo_bundle_add_message() functions.
+ *
+ * \param targ The address to send the bundle to
+ * \param serv The server socket to send the bundle from 
+ *              (can be NULL to use new socket)
+ * \param b    The bundle itself
+ */
+int lo_send_bundle_from(lo_address targ, lo_server serv, lo_bundle b);
+
 /**
  * \brief Create a new lo_message object
  */
@@ -343,7 +374,7 @@ lo_server lo_server_new(const char *port, lo_err_handler err_h);
  * \param port If using UDP then NULL may be passed to find an unused port.
  * Otherwise a decimal port number orservice name or may be passed.
  * If using UNIX domain sockets then a socket path should be passed here.
- * \param proto The protocol to use, should be one of LO_UDP, or LO_UNIX.
+ * \param proto The protocol to use, should be one of LO_UDP, LO_TCP or LO_UNIX.
  * \param err_h An error callback function that will be called if there is an
  * error in messge reception or server creation. Pass NULL if you do not want
  * error handling.
@@ -386,7 +417,7 @@ int lo_server_recv(lo_server s);
  * \param typespec The typespec the method accepts. Incoming messages with
  * similar typespecs (e.g. ones with numerical types in the same position) will
  * be coerced to the typespec given here.
- * \param h The method handler callback function that will be called it a
+ * \param h The method handler callback function that will be called if a
  * matching message is received
  * \param user_data A value that will be passed to the callback function, h,
  * when its invoked matching from this method.
@@ -435,11 +466,14 @@ int lo_server_get_port(lo_server s);
  */
 char *lo_server_get_url(lo_server s);
 
-/** \brief Return true if there are scheduled events (eg. from bundles) waiting
- *  * to be dispatched by the server */
+/** 
+ * \brief Return true if there are scheduled events (eg. from bundles) 
+ * waiting to be dispatched by the server
+ */
 int lo_server_events_pending(lo_server s);
 
-/** \brief Return the time in seconds until the next scheduled event.
+/** 
+ * \brief Return the time in seconds until the next scheduled event.
  *
  * If the delay is greater than 100 seconds then it will return 100.0.
  */
@@ -508,6 +542,11 @@ int lo_send_internal(lo_address t, const char *file, const int line,
 /** \brief the real send_timestamped function (don't call directly) */
 int lo_send_timestamped_internal(lo_address t, const char *file, const int line,
      lo_timetag ts, const char *path, const char *types, ...);
+/** \brief the real lo_send_from function (don't call directly) */
+int lo_send_from_internal(lo_address targ, lo_server from, const char *file, 
+     const int line, const lo_timetag ts, 
+     const char *path, const char *types, ...);
+
 
 /** \brief Find the time difference between two timetags
  *
