@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: lo_macros.h,v 1.3 2005/02/28 14:33:19 theno23 Exp $
+ *  $Id: lo_macros.h,v 1.5 2005/12/05 22:22:09 nhumfrey Exp $
  */
 
 #ifndef LO_MACROS_H
@@ -23,7 +23,8 @@
 extern "C" {
 #endif
 
-/* Maximum length of UDP messages in bytes */
+/* \brief Maximum length of UDP messages in bytes
+ */
 #define LO_MAX_MSG_SIZE 32768
 
 /* \brief A set of macros to represent different communications transports
@@ -45,14 +46,9 @@ extern "C" {
         lo_send_timestamped_internal(targ, __FILE__, __LINE__, ts, path, \
 		       	             types, LO_MARKER_A, LO_MARKER_B)
 
-#if 0
-
-This function is deliberatly not avialable, see send.c for details.
-
-#define lo_sendf(targ, path...) \
-        lo_sendf_internal(targ, __FILE__, __LINE__, path, \
-			 LO_MARKER_A, LO_MARKER_B)
-#endif
+#define lo_send_from(targ, from, ts, path, types...) \
+        lo_send_from_internal(targ, from, __FILE__, __LINE__, ts, path, \
+		       	             types, LO_MARKER_A, LO_MARKER_B)
 
 #ifdef __cplusplus
 }
