@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: lo_types.h,v 1.2 2004/11/04 10:33:36 theno23 Exp $
+ *  $Id: lo_types.h,v 1.3 2005/04/25 21:46:47 xovo Exp $
  */
 
 #ifndef LO_TYPES_H
@@ -21,7 +21,13 @@
 extern "C" {
 #endif
 
+#ifdef WIN32
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#else
 #include <netdb.h>
+#endif
+
 #include <pthread.h>
 
 #include "lo/lo_osc_types.h"
