@@ -1,7 +1,13 @@
 #ifndef LO_TYPES_H
 #define LO_TYPES_H
 
+#ifdef WIN32
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#else
 #include <netdb.h>
+#endif
+
 #include <pthread.h>
 
 #include "lo/lo_osc_types.h"
@@ -84,6 +90,7 @@ typedef struct _lo_strlist {
 typedef union {
     int32_t  i;
     float    f;
+    char     c;
     uint32_t nl;
 } lo_pcast32;
     
