@@ -11,13 +11,19 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: message.c,v 1.5 2005/01/19 07:59:50 theno23 Exp $
+ *  $Id: message.c,v 1.7 2005/08/11 09:07:29 mhabets Exp $
  */
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+
+#ifdef WIN32
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#else
 #include <netinet/in.h>
+#endif
 
 #include "lo_types_internal.h"
 #include "lo/lo.h"
@@ -158,7 +164,7 @@ void lo_message_add_char(lo_message m, char a)
     lo_pcast32 b;
     int32_t *nptr = lo_message_add_data(m, sizeof(int32_t));
 
-    b.i = a;
+    b.c = a;
 
     lo_message_add_typechar(m, LO_CHAR);
     *nptr = lo_htoo32(b.nl);
@@ -420,7 +426,7 @@ void lo_arg_pp_internal(lo_type type, void *data, int bigendian)
 	break;
 
     case LO_CHAR:
-	printf("'%c'", (char)val32.i);
+	printf("'%c'", (char)val32.c);
 	break;
 
     case LO_MIDI:
