@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: server.c,v 1.25 2005/09/02 22:41:07 theno23 Exp $
+ *  $Id: server.c,v 1.27 2006/01/26 15:00:28 nhumfrey Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -57,7 +57,7 @@ typedef struct {
     void *next;
 } queued_msg_list;
 
-struct lo_cs lo_client_sockets = {0, 0};
+struct lo_cs lo_client_sockets = {-1, -1};
 
 static int lo_can_coerce_spec(const char *a, const char *b);
 static int lo_can_coerce(char a, char b);
@@ -207,10 +207,10 @@ lo_server lo_server_new_with_proto(const char *port, int proto,
 	return NULL;
     }
 
-#ifdef DISABLE_IPV6
-    hints.ai_family = PF_INET;
-#else
+#ifdef ENABLE_IPV6
     hints.ai_family = PF_UNSPEC;
+#else
+    hints.ai_family = PF_INET;
 #endif
     hints.ai_flags = AI_PASSIVE;
 
@@ -678,12 +678,13 @@ static void dispatch_method(lo_server s, const char *path, char *types,
 	hostname[0] = '\0';
 	portname[0] = '\0';
     }
-
-    free(src->host);
-    free(src->port);
-
-    src->host = hostname;
-    src->port = portname;
+    
+    
+    // Store the source information in the lo_address
+    if (src->host) free(src->host);
+    if (src->host) free(src->port);
+    src->host = strdup(hostname);
+    src->port = strdup(portname);
     src->proto = s->protocol;
 
     for (it = s->first; it; it = it->next) {
@@ -822,12 +823,12 @@ static void dispatch_method(lo_server s, const char *path, char *types,
 
     free(argv);
 
-    /* the address got assigned static stuff, hence not using address_free */
-    free(src);
 
     /* these are already part of data and will be freed later */
     msg->data = NULL;
     msg->types = NULL;
+    
+    lo_address_free(src);
     lo_message_free(msg);
 }
 
