@@ -11,7 +11,7 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: server_thread.c,v 1.4 2005/08/09 15:06:05 mhabets Exp $
+ *  $Id: server_thread.c,v 1.8 2006/01/26 15:00:28 nhumfrey Exp $
  */
 
 #include <unistd.h>
@@ -56,7 +56,6 @@ void lo_server_thread_free(lo_server_thread st)
     if (st) {
 	if (st->active) {
 	    lo_server_thread_stop(st);
-	    /* pthread_cancel(st->thread); */
 	}
 	lo_server_free(st->s);
     }
@@ -78,23 +77,34 @@ void lo_server_thread_del_method(lo_server_thread st, const char *path,
 
 void lo_server_thread_start(lo_server_thread st)
 {
+    int result;
+	
     if (!st->active) {
 	st->active = 1;
 	st->done = 0;
-	pthread_create(&(st->thread), NULL, (void *)&thread_func, st);
+	
+	// Create the server thread
+	result = pthread_create(&(st->thread), NULL, (void *)&thread_func, st);
+	if (result) {
+	    fprintf(stderr, "Failed to create thread: pthread_create() returned %s\n", strerror(result));
+	}
+	
     }
 }
 
 void lo_server_thread_stop(lo_server_thread st)
 {
+    int result;
+
     if (st->active) {
+	// Signal thread to stop
 	st->active = 0;
-	while (!st->done) {
-#ifdef WIN32
-        Sleep(1);
-#else
-	    usleep(1000);
-#endif
+	
+	// pthread_join waits for thread to terminate 
+	// and then releases the thread's resources
+	result = pthread_join( st->thread, NULL );
+	if (result) {
+	    fprintf(stderr, "Failed to stop thread: pthread_join() returned %s\n", strerror(result));
 	}
     }
 }
@@ -109,6 +119,11 @@ char *lo_server_thread_get_url(lo_server_thread st)
     return lo_server_get_url(st->s);
 }
 
+lo_server lo_server_thread_get_server(lo_server_thread st) 
+{
+    return st->s;
+}
+
 int lo_server_thread_events_pending(lo_server_thread st)
 {
     return lo_server_events_pending(st->s);
@@ -122,6 +137,8 @@ static void thread_func(void *data)
 	lo_server_recv_noblock(st->s, 10);
     }
     st->done = 1;
+    
+    pthread_exit(NULL);
 }
 
 void lo_server_thread_pp(lo_server_thread st)
