@@ -11,11 +11,12 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  $Id: subtest.c,v 1.1 2005/03/02 16:55:53 theno23 Exp $
+ *  $Id: subtest.c,v 1.4 2005/07/05 13:26:23 theno23 Exp $
  */
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 
 #include "lo/lo.h"
@@ -40,7 +41,11 @@ int main(int argc, char *argv[])
     t = lo_address_new_from_url(argv[1]);
     lo_send(t, "/subtest", "i", 0xf00);
 
+#ifdef WIN32
+    Sleep(4000);
+#else
     sleep(4);
+#endif
 
     return 0;
 }
@@ -50,8 +55,21 @@ int subtest_handler(const char *path, const char *types, lo_arg **argv,
 {
     int i;
     lo_address a = lo_message_get_source(data);
+    static char *uri = NULL;
 
     printf("subtest: got reply (%s)\n", path);
+    if (!uri) {
+	uri = lo_address_get_url(a);
+    } else {
+	char *new_uri = lo_address_get_url(a);
+
+	if (strcmp(uri, new_uri)) {
+	    printf("ERROR: %s != %s\n", uri, new_uri);
+
+	    exit(1);
+	}
+	free(new_uri);
+    }
     lo_send(a, "/subtest-reply", "i", 0xbaa);
     if (lo_address_errno(a)) {
 	fprintf(stderr, "subtest error %d: %s\n", lo_address_errno(a),
@@ -61,9 +79,16 @@ int subtest_handler(const char *path, const char *types, lo_arg **argv,
     }
 
     for (i=0; i<10; i++) {
-	usleep(2233);
+#ifdef WIN32
+        /* TODO: Wait time of 2.233 not easily doable in Windows */
+        Sleep(2);
+#else
+        usleep(2233);
+#endif
 	lo_send(a, "/subtest-reply", "i", 0xbaa+i);
     }
+
+    return 0;
 }
 
 /* vi:set ts=8 sts=4 sw=4: */
